-- **************************************************************************
--   TitanTreasuryConfig.lua
-- 
--   By: KanadiaN
--         (Lindarena@Laughing Skull)
-- **************************************************************************

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Titan", true )
local LB = LibStub( "AceLocale-3.0" ):GetLocale( "TitanTreasury", true );
local AceConfigDialog = LibStub( "AceConfigDialog-3.0" );
local AceConfig = LibStub( "AceConfig-3.0" );

-- **************************************************************************
-- NAME : Core Vars
-- DESC : These are here so they do not get changed like the locales would
-- **************************************************************************

local PlugInName = "TitanTreasury";
LB["TITAN_TREASURY_CORE_ID"] = "Treasury";
LB["TITAN_TREASURY_CORE_VERSION"] = GetAddOnMetadata( PlugInName, "Version" );
LB["TITAN_TREASURY_CORE_DTAG"] = "|cffff0000<TitanTreasury Debug>|r %s";
LB["TITAN_TREASURY_CORE_ITAG"] = "|cffff9900<TitanTreasury>|r %s";
LB["TITAN_TREASURY_CORE_ETAG"] = "|cffff9900<TitanTreasury Error>|r %s";

LB["TITAN_TREASURY_CORE_ADDVER"] = "r4";
LB["TITAN_TREASURY_CORE_DBVER"] = tonumber( 1 );
--LB["TITAN_TREASURY_CORE_ARTWORK"] = "Interface\\AddOns\\TitanTreasury\\Artwork\\TitanTreasury";
LB["TITAN_TREASURY_CORE_ARTWORK"] = "Interface\\ICONS\\INV_Misc_Coin_17";

-- **************************************************************************
-- NAME : TitanTreasury_ConfigUtils( action )
-- DESC : Pull information from .toc for config dialog
-- **************************************************************************
local function TitanTreasury_ConfigUtils( action )
     if ( action == "GetAuthor" ) then
          return GetAddOnMetadata( PlugInName, "Authors" );
     elseif ( action == "GetTranslation" ) then
          return GetAddOnMetadata( PlugInName, "X-Translation" );
     elseif ( action == "GetCategory" ) then
          return GetAddOnMetadata( PlugInName, "X-Category" );
     elseif ( action == "GetEmail" ) then
          return GetAddOnMetadata( PlugInName, "X-Email" );
     elseif ( action == "GetWebsite" ) then
          return GetAddOnMetadata( PlugInName, "X-Website" );
     elseif ( action == "GetVersion" ) then
          return tostring( GetAddOnMetadata( PlugInName, "Version" ) );
     end
end

-- **************************************************************************
-- NAME : MoneyOpts
-- DESC : Config Dialog Setup
-- **************************************************************************
local EstateOpts = {
     type = "group",
     name = LB["TITAN_TREASURY_CONFIG"],
     args = {
          confgendesc = {
               type = "description", order = 1,
               name = LB["TITAN_TREASURY_CONFIG_LABEL"],
               cmdHidden = true
          },
	  cat1 = {
               type = "group", order = 2, inline = true,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_ABOUT"],
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_ABOUT_DESC"],
               args = {
                    confversiondesc = {
                         type = "description", order = 1,
                         name = LB["TITAN_TREASURY_ABOUT_VERSION"]:format( TitanTreasury_ConfigUtils( "GetVersion" ) ),
                         cmdHidden = true
                    },
                    confauthordesc = {
                         type = "description", order = 2,
                         name = LB["TITAN_TREASURY_ABOUT_AUTHOR"]:format( TitanTreasury_ConfigUtils( "GetAuthor" ) ),
                         cmdHidden = true
                    },
                    conflangauthordesc = {
                         type = "description", order = 3,
                         name = LB["TITAN_TREASURY_ABOUT_TRANSLATION"]:format( TitanTreasury_ConfigUtils( "GetTranslation" ) ),
                         cmdHidden = true
                    },
                    confcatdesc = {
                         type = "description", order = 4,
                         name = LB["TITAN_TREASURY_ABOUT_CATEGORY"]:format( TitanTreasury_ConfigUtils( "GetCategory" ) ),
                         cmdHidden = true
                    },
                    confemaildesc = {
                         type = "description", order = 5,
                         name = LB["TITAN_TREASURY_ABOUT_EMAIL"]:format( TitanTreasury_ConfigUtils( "GetEmail" ) ),
                         cmdHidden = true
                    },
                    confwebsitedesc = {
                         type = "description", order = 6,
                         name = LB["TITAN_TREASURY_ABOUT_WEBSITE"]:format( TitanTreasury_ConfigUtils( "GetWebsite" ) ),
                         cmdHidden = true
                    },
                    confmemorydesc = {
                         type = "description", order = 7,
                         name = function()
                              UpdateAddOnMemoryUsage();
                              mem = floor( GetAddOnMemoryUsage( PlugInName ) );
                              return LB["TITAN_TREASURY_ABOUT_MEMORY"]:format( mem );
                         end,
                         cmdHidden = true,
                    },
                    LoadBannor = {
                         type = "toggle", order = 8,
                         name = LB["TITAN_TREASURY_CONFIG_BANNOR"],
                         desc = LB["TITAN_TREASURY_CONFIG_BANNOR_DESC"],
                         get = function() return TitanTreasury.General.DisplayB; end,
                         set = function( _, value ) TitanTreasury.General.DisplayB = value; end,
                    },
               },
          },
          cat2 = { -- Settings & Tooltip
               type = "group", order = 3, -- inline = true,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_TOOLTIP"],
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_TOOLTIP_DESC"],
               args = {
                    tooltipTimer = { -- Tooltip Update Timer
                         type = "group", order = 1, inline = true,
                         name = LB["TITAN_TREASURY_CONFIG_GROUP_TOOLTIP_INLINE_TIMER"], -- "Tooltip Update Timer",
                         args = {
                              tTimer = {
                                   type = "toggle", order = 1,
                                   name = LB["TITAN_TREASURY_CONFIG_TOOLTIP_INLINE_TIMER"], -- "Update Timer",
                                   desc = LB["TITAN_TREASURY_CONFIG_TOOLTIP_INLINE_TIMER_DESC"], -- "This will allow the tooltip to update when it is being displayed",
                                   get = function() return TitanTreasury.General.tooltipTimer; end,
                                   set = function( _, value )
                                        if ( value ~= TitanTreasury.General.tooltipTimer ) then
                                             TitanTreasury.General.tooltipTimer = value;
                                             if ( value ) then
                                                  TitanTreasury_CoreUtils( "tooltipTimer", "start" );
                                             elseif ( not value ) then
                                                  TitanTreasury_CoreUtils( "tooltipTimer", "stop" );
                                             end
                                        end
                                   end,
                              },
                              timerRange = {
                                   type = "range", order = 2, width = "full",
                                   name = LB["TITAN_TREASURY_CONFIG_TOOLTIP_INLINE_INTERVAL"], --"Timer Interval",
                                   desc = LB["TITAN_TREASURY_CONFIG_TOOLTIP_INLINE_INTERVAL_DESC"], -- "Sets how often the tooltip will update. ( in seconds )",
                                   hidden = function()
                                        return not TitanTreasury.General.tooltipTimer;
                                   end,
                                   min = 1,
                                   max = 5,
                                   step = 1,
                                   get = function() return TitanTreasury.General.timerInterval; end,
                                   set = function( _, value )
                                        if ( value ~= TitanTreasury.General.timerInterval ) then
                                             TitanTreasury.General.timerInterval = value;
                                             TitanTreasury_CoreUtils( "tooltipTimer", "restart" );
                                        end
                                   end,
                              },
                         },
                    },
                    tooltipCategories = {
                         type = "group", order = 3, inline = true,
                         name = LB["TITAN_TREASURY_CONFIG_GROUP_CATEGORY_DISPLAY"], -- "Category Display",
                         args = {
                              ShowGuildRep = {
                                   type = "toggle", order = 1,
                                   name = LB["TITAN_TREASURY_CONFIG_DISPLAY_GUILDREP"], -- "Show Guild Rep",
                                   desc = LB["TITAN_TREASURY_CONFIG_DISPLAY_GUILDREP_DESC"], -- "This will display your guild reputation in the tooltip.",
                                   disabled = function() return not IsInGuild(); end,
                                   get = function() return TitanTreasury.General.ShowGuildRep; end,
                                   set = function( _, value ) TitanTreasury.General.ShowGuildRep = value; end,
                              },
                              ShowTokens = {
                                   type = "toggle", order = 2,
                                   name = LB["TITAN_TREASURY_CONFIG_DISPLAY_TOKENS"], -- "Show Tokens",
                                   desc = LB["TITAN_TREASURY_CONFIG_DISPLAY_TOKENS_DESC"], -- "This will show your tokens on the tooltip.",
                                   get = function() return TitanTreasury.General.ShowTokens; end,
                                   set = function( _, value ) TitanTreasury.General.ShowTokens = value; end,
                              },
                              ShowAlts = {
                                   type = "toggle", order = 3,
                                   name = LB["TITAN_TREASURY_CONFIG_DISPLAY_ALTS"], -- "Show Alts",
                                   desc = LB["TITAN_TREASURY_CONFIG_DISPLAY_ALTS_DESC"], -- "This will put alts info on the tooltip.",
                                   get = function() return TitanTreasury.General.ShowAlts; end,
                                   set = function( _, value ) TitanTreasury.General.ShowAlts = value; end,
                              },
                              ShowMem = {
                                   type = "toggle", order = 4,
                                   name = LB["TITAN_TREASURY_CONFIG_DISPLAY_SHOWMEM"],
                                   desc = LB["TITAN_TREASURY_CONFIG_DISPLAY_SHOWMEM_DESC"],
                                   get = function() return TitanTreasury.General.ShowMem; end,
                                   set = function( _, value ) TitanTreasury.General.ShowMem = value; end,
                              },
                         },
                    },
                    tooltipDividerStyle = {
                         type = "group", order = 4, inline = true,
                         name = LB["TITAN_TREASURY_CONFIG_GROUP_CATEGORY_DIVIDER"], -- "Category Divider Style",
                         args = {
                              dStyle = {
                                   type = "select", order = 1,
                                   name = LB["TITAN_TREASURY_CONFIG_DIVIDER_STYLE"], -- "Tooltip Divider Style",
                                   desc = LB["TITAN_TREASURY_CONFIG_DIVIDER_STYLE_DESC"], -- "Changes the category divider style.",
                                   get = function() return TitanTreasury.General.dStyle; end,
                                   set = function( _, value )
                                        TitanTreasury.General.dStyle = value;
                                        TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                                        collectgarbage( "collect" );
                                   end,
                                   values = function()
                                        local preList = {};
                                        table.foreach( TitanTreasuryStaticArrays.dStyles, function( Key, Data )
                                                  if ( Data.Value ~= TitanTreasury.General.dStyle ) then
                                                       preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                                  else
                                                       preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                                  end
                                             end
                                        );
                                        return preList;
                                   end,
                              },
                              dType = {
                                   type = "select", order = 2,
                                   name = LB["TITAN_TREASURY_CONFIG_DIVIDER_TYPE"], -- "Tooltip Divider Type",
                                   desc = LB["TITAN_TREASURY_CONFIG_DIVIDER_TYPE_DESC"], -- "Changes the category divider type.",
                                   get = function() return TitanTreasury.General.dType; end,
                                   set = function( _, value )
                                        TitanTreasury.General.dType = value;
                                        TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                                        collectgarbage( "collect" );
                                   end,
                                   values = function()
                                        local preList = {};
                                        table.foreach( TitanTreasuryStaticArrays.dTypes, function( Key, Data )
                                                  if ( Data.Value ~= TitanTreasury.General.dType ) then
                                                       preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                                  else
                                                       preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                                  end
                                             end
                                        );
                                        return preList;
                                   end,
                              },
                              dColor = {
                                   type = "select", order = 3,
                                   name = LB["TITAN_TREASURY_CONFIG_DIVIDER_COLOR"], -- "Tooltip Divider Color",
                                   desc = LB["TITAN_TREASURY_CONFIG_DIVIDER_COLOR_DESC"], -- "Changes the category divider color.",
                                   get = function() return TitanTreasury.General.dColor; end,
                                   set = function( _, value )
                                        TitanTreasury.General.dColor = value;
                                        TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                                        collectgarbage( "collect" );
                                   end,
                                   values = function()
                                        local preList = {};
                                        table.foreach( TitanTreasuryStaticArrays.dColors, function( Key, Data )
                                                  if ( Data.Value ~= "CLASS" ) then
                                                       preList[Data.Value] = TitanTreasury_ColorUtils( "GetCText", Data.Name, Data.Name );
                                                  elseif ( Data.Value == "CLASS" ) then
                                                       preList[Data.Value] = TitanTreasury_ColorUtils( "GetCClass", UnitClass( "player" ), Data.Name );
                                                  end
                                             end
                                        );
                                        return preList;
                                   end,
                              },
                         },
                    },
               },
          },
          cat3 = { -- Button Settings
               type = "group", order = 4,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_BUTTON"],
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_BUTTON_DESC"],
               args = {
                    displayType = {
                         type = "select", order = 1,
                         name = LB["TITAN_TREASURY_CONFIG_BUTTON_TYPE"], -- "Display Type",
                         desc = LB["TITAN_TREASURY_CONFIG_BUTTON_TYPE_DESC"], -- "The type information that will be shown on the button.",
                         get = function() return TitanTreasury.Button.Mode; end,
                         set = function( _, value )
                              TitanTreasury.Button.Mode = value;
                              TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Modes, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Button.Mode ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end,
                    },
                    buttonType = {
                         type = "select", order = 2,
                         name = LB["TITAN_TREASURY_CONFIG_BUTTON_MONEY_TYPE"], -- "Money Type",
                         desc = LB["TITAN_TREASURY_CONFIG_BUTTON_MONEY_TYPE_DESC"], -- "This will make the money show in text or coin.",
                         get = function() return TitanTreasury.Button.Type; end,
                         set = function( _, value )
                              TitanTreasury.Button.Type = value;
                              TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Types, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Button.Type ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
                    buttonStyle = {
                         type = "select", order = 3,
                         name = LB["TITAN_TREASURY_CONFIG_BUTTON_MONEY_STYLE"], -- "Money Style",
                         desc = LB["TITAN_TREASURY_CONFIG_BUTTON_MONEY_STYLE_DESC"], -- "This will show the money in plain or colored text.",
                         get = function() return TitanTreasury.Button.Style; end,
                         set = function( _, value )
                              TitanTreasury.Button.Style = value;
                              TitanPanelButton_UpdateButton( LB["TITAN_TREASURY_CORE_ID"] );
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Styles, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Button.Style ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
               },
          },
          cat4 = { -- Guild Reputation
               type = "group", order = 5,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_GUILDREP"], -- "Guild Rep",
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_GUILDREP_DESC"], -- "Shows Guild Related Repuataions.",
               hidden = function() return not TitanTreasury.General.ShowGuildRep; end,
               args = {
                    --[[
                    ShowGain = {
                         type = "toggle", order = 1,
                         name = "Show Gains",
                         desc = "Shows session gain |cffff0000( This might get removed )|r.",
                         get = function() return TitanTreasury.Guild.ShowGain; end,
                         set = function( _, value ) TitanTreasury.Guild.ShowGain = value; end,
                    },
                    ]]--
                    ShowPercent = {
                         type = "toggle", order = 2,
                         name = LB["TITAN_TREASURY_CONFIG_GUILDREP_PERCENT"], -- "Show Percent",
                         desc = LB["TITAN_TREASURY_CONFIG_GUILDREP_PERCENT_DESC"], -- "Shows persectage of current reputation level.",
                         get = function() return TitanTreasury.Guild.ShowPercent; end,
                         set = function( _, value ) TitanTreasury.Guild.ShowPercent = value; end,
                    },
                    ShowRaw = {
                         type = "toggle", order = 3,
                         name = LB["TITAN_TREASURY_CONFIG_GUILDREP_RAW"], -- "Show Raw",
                         desc = LB["TITAN_TREASURY_CONFIG_GUILDREP_RAW_DESC"], -- "Shows raw value data.",
                         get = function() return TitanTreasury.Guild.ShowRaw; end,
                         set = function( _, value ) TitanTreasury.Guild.ShowRaw = value; end,
                    },
                    ShowRemain = {
                         type = "toggle", order = 4,
                         name = LB["TITAN_TREASURY_CONFIG_GUILDREP_REMAIN"], -- "Show Remaining Rep",
                         desc = LB["TITAN_TREASURY_CONFIG_GUILDREP_REMAIN_DESC"], -- "Shows the amount of reputation to go.",
                         get = function() return TitanTreasury.Guild.ShowRemain; end,
                         set = function( _, value ) TitanTreasury.Guild.ShowRemain = value; end,
                    },
                    ShowRepText = {
                         type = "toggle", order = 5,
                         name = LB["TITAN_TREASURY_CONFIG_GUILDREP_TEXT"], -- "Show Rep Text",
                         desc = LB["TITAN_TREASURY_CONFIG_GUILDREP_TEXT_DESC"], -- "Shows reputation level.",
                         get = function() return TitanTreasury.Guild.ShowRepText; end,
                         set = function( _, value ) TitanTreasury.Guild.ShowRepText = value; end,
                    },
                    TextStyle = {
                         type = "select", order = 7,
                         name = LB["TITAN_TREASURY_CONFIG_GUILDREP_TEXTSTYLE"], -- "Text Style",
                         desc = LB["TITAN_TREASURY_CONFIG_GUILDREP_TEXTSTYLE_DESC"], -- "Here you can chose if you want colored or plain text.",
                         get = function() return TitanTreasury.Guild.Style; end,
                         set = function( _, value )
                              TitanTreasury.Guild.Style = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Styles, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Guild.Style ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
               },
          },
          cat5 = { -- Coin Settings
               type = "group", order = 6,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_COIN"], -- "Currency",
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_COIN_DESC"], -- "Settings for how currency is displayed.",
               args = {
                    Type = {
                         type = "select", order = 1,
                         name = LB["TITAN_TREASURY_CONFIG_COIN_TYPE"], -- "Money Type",
                         desc = LB["TITAN_TREASURY_CONFIG_COIN_TYPE_DESC"], -- "This will make the money show in text or coin.",
                         get = function() return TitanTreasury.Coins.Type; end,
                         set = function( _, value )
                              TitanTreasury.Coins.Type = value;
                              collectgarbage( "collect" );
                          end,
                          values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Types, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Coins.Type ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
                    Style = {
                         type = "select", order = 2,
                         name = LB["TITAN_TREASURY_CONFIG_COIN_STYLE"], -- "Money Style",
                         desc = LB["TITAN_TREASURY_CONFIG_COIN_STYLE_DESC"], -- "This will show the money in plain or colored text.",
                         get = function() return TitanTreasury.Coins.Style; end,
                         set = function( _, value )
                              TitanTreasury.Coins.Style = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Styles, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Coins.Style ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
                    sTypes = {
                         type = "select", order = 3,
                         name = LB["TITAN_TREASURY_CONFIG_COIN_SORT_TYPES"],
                         desc = LB["TITAN_TREASURY_CONFIG_COIN_SORT_TYPES_DESC"],
                         get = function() return TitanTreasury.Sort.sType; end,
                         set = function( _, value )
                              TitanTreasury.Sort.sType = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.sTypes, function( key, value )
                                        if ( TitanTreasury.Sort.sType == value ) then
                                             preList[value] = ( "|cffffff9a%s|r" ):format( value );
                                        else
                                             preList[value] = value;
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
                    sMethod = {
                         type = "select", order = 4,
                         name = LB["TITAN_TREASURY_CONFIG_COIN_SORT_METHOD"],
                         desc = LB["TITAN_TREASURY_CONFIG_COIN_SORT_METHOD_DESC"],
                         get = function() return TitanTreasury.Sort.sMethod; end,
                         set = function( _, value )
                              TitanTreasury.Sort.sMethod = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.sMethod, function( key, value )
                                        if ( TitanTreasury.Sort.sMethod == value ) then
                                             preList[value] = ( "|cffffff9a%s|r" ):format( value );
                                        else
                                             preList[value] = value;
                                        end
                                   end
                              )
                              return preList;
                         end
                    },
               },
          },
          Cat6 = { -- Tokens
               type = "group", order = 7,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_TOKEN"], -- "Tokens",
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_TOKEN_DESC"], -- "Settings for how tokens are displayed.",
               hidden = function() return not TitanTreasury.General.ShowTokens; end,
               args = {
                    ShowTokensIcon = {
                         type = "toggle", order = 1,
                         name = LB["TITAN_TREASURY_CONFIG_TOKEN_ICON"], -- "Show Tokens Icon",
                         desc = LB["TITAN_TREASURY_CONFIG_TOKEN_ICON_DESC"], -- "This will show the Tokens icon on the tooltip.",
                         get = function() return TitanTreasury.Tokens.TokenIcon; end,
                         set = function( _, value ) TitanTreasury.Tokens.TokenIcon = value; end,
                    },
                    ShowTokensName = {
                         type = "toggle", order = 2,
                         name = LB["TITAN_TREASURY_CONFIG_TOKEN_NAME"], -- "Show Token Names",
                         desc = LB["TITAN_TREASURY_CONFIG_TOKEN_NAME_DESC"], -- "This will show the Tokens name on the tooltip.",
                         hidden = function() return not TitanTreasury.Tokens.TokenIcon; end,
                         get = function() return TitanTreasury.Tokens.TokenName; end,
                         set = function( _, value ) TitanTreasury.Tokens.TokenName = value; end,
                    },
                    TokenIconSize = {
                         type = "select", order = 3,
                         name = LB["TITAN_TREASURY_CONFIG_TOKEN_SIZE"], -- "Token Icon Size",
                         desc = LB["TITAN_TREASURY_CONFIG_TOEKN_SIZE_DESC"], -- "This will change the size of the icon on the tooltip.",
                         hidden = function() return not TitanTreasury.Tokens.TokenIcon; end,
                         get = function() return TitanTreasury.Tokens.TokenIconSize; end,
                         set = function( _, value ) 
                              TitanTreasury.Tokens.TokenIconSize = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.iSize, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Tokens.TokenIconSize ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              );
                              return preList;
                         end
                    },
                    TokensTextStyle = {
                         type = "select", order = 4,
                         name = LB["TITAN_TREASURY_CONFIG_TOKEN_STYLE"], -- "Tokens Text Style",
                         desc = LB["TITAN_TREASURY_CONFIG_TOKEN_STYLE_DESC"], -- "This will make the tokens text show up in plain or colored text.",
                         get = function() return TitanTreasury.Tokens.TokenColored; end,
                         set = function( _, value ) 
                              TitanTreasury.Tokens.TokenColored = value;
                              collectgarbage( "collect" );
                         end,
                         values = function()
                              local preList = {};
                              table.foreach( TitanTreasuryStaticArrays.Styles, function( Key, Data )
                                        if ( Data.Value ~= TitanTreasury.Tokens.TokenColored ) then
                                             preList[Data.Value] = ( "|cff19ff19%s|r" ):format( Data.Name );
                                        else
                                             preList[Data.Value] = ( "|cffffff9a%s|r" ):format( Data.Name );
                                        end
                                   end
                              )
                              return preList;
                         end
                    },
               },
          },
          cat7 = { -- Sessions
               type = "group", order = 8,
               name = LB["TITAN_TREASURY_CONFIG_GROUP_SESSION"], -- "Session Data",
               desc = LB["TITAN_TREASURY_CONFIG_GROUP_SESSION_DESC"], -- "Settings for how session data is handled.",
               args = {
                    ShowSessionData = {
                         type = "toggle", order = 1,
                         name = LB["TITAN_TREASURY_CONFIG_SESSION_DATA"], -- "Show Session Data",
                         desc = LB["TITAN_TREASURY_CONFIG_SESSION_DATA_DESC"], -- "Show session data on tooltip",
                         get = function() return TitanTreasury.Sessions.ShowSession; end,
                         set = function( _, value ) TitanTreasury.Sessions.ShowSession = value; end,
                    },
                    ShowSessionHourlyData = {
                         type = "toggle", order = 2,
                         name = LB["TITAN_TREASURY_CONFIG_SESSION_HOURLY"], -- "Show Hourly Session Data",
                         desc = LB["TITAN_TREASURY_CONFIG_SESSION_HOURLY_DESC"], -- "Show hourly session data on tooltip",
                         get = function() return TitanTreasury.Sessions.ShowHourly; end,
                         set = function( _, value ) TitanTreasury.Sessions.ShowHourly = value; end,
                    },
               },
          },
     },
};

-- **************************************************************************
-- NAME : TitanPanelMoneyButton_OnLoad( self )
-- DESC : Registers the plugin upon it loading
-- tooltipTitle = LB["TITAN_TREASURY_TOOLTIP"],
-- **************************************************************************
function TitanPanelTreasuryButton_OnLoad( self )
     self.registry = {
          id = LB["TITAN_TREASURY_CORE_ID"],
          builtIn = false,
          category = "Information",
          version = TITAN_VERSION,
          menuText = LB["TITAN_TREASURY_MENU_TEXT"],
          tooltipTitle = LB["TITAN_TREASURY_TOOLTIP"],
          tooltipTextFunction = "TitanPanelTreasuryButton_GetTooltipText",
          buttonTextFunction = "TitanPanelTreasuryButton_GetButtonText",
          icon = LB["TITAN_TREASURY_CORE_ARTWORK"],
          iconWidth = 16,
          savedVariables = {
	       ShowIcon = 1,
	       ShowLabelText = 1,
          },
     };

     self:RegisterEvent( "ADDON_LOADED" );
     self:RegisterEvent( "PLAYER_MONEY" );
     self:RegisterEvent( "PLAYER_ENTERING_WORLD" );

     -- Titan Alts Config
     AceConfig:RegisterOptionsTable( PlugInName, EstateOpts );
     AceConfigDialog:AddToBlizOptions( PlugInName, LB["TITAN_TREASURY_CONFIG"] );
end

function TitanPanelTreasuryButton_SetTooltipTitle()
     local TTFR = TitanTreasury_ColorUtils( "GetCFaction", TitanTreasuryProfile.Faction, ( "%s-%s" ):format( TitanTreasuryProfile.Faction, TitanTreasuryProfile.Realm ) );
     local ttUser = TitanTreasury_ColorUtils( "GetCClass", CT.Class, TitanTreasuryProfile.Player );
     return LB["TITAN_TREASURY_TITLE"]:format( ttUser, TTFR );
end

-- **************************************************************************
-- NAME : SLASH_TITANPALS*
-- DESC : Slash command setup
-- **************************************************************************
SLASH_TitanTreasury1 = "/TitanTreasury";
SLASH_TitanTreasury2 = "/tt";
SlashCmdList["TitanTreasury"] = function( msg )
     TitanTreasury_CommandHandler( "TitanTreasury", msg );
end

-- **************************************************************************
-- NAME : TitanTreasury_ShowHelp( cmd )
-- DESC : Slash command help display
-- **************************************************************************
function TitanTreasury_ShowHelp( cmd )
     TitanTreasury_DebugUtils( "Info", "help", 661, LB["TITAN_TREASURY_HELP_LINE1"] );
     TitanTreasury_DebugUtils( "Info", "help", 662, LB["TITAN_TREASURY_HELP_LINE2"]:format( cmd ) );
     TitanTreasury_DebugUtils( "Info", "help", 663, LB["TITAN_TREASURY_HELP_LINE3"]:format( cmd ) );
     TitanTreasury_DebugUtils( "Info", "help", 664, LB["TITAN_TREASURY_HELP_LINE4"]:format( cmd ) );
     TitanTreasury_DebugUtils( "Info", "help", 665, LB["TITAN_TREASURY_HELP_LINE5"]:format( cmd ) );
     local auth = TitanTreasury_CoreUtils( "Author", ( "%s@%s" ):format( TitanTreasuryProfile.Player, TitanTreasuryProfile.Realm ) )
     if ( auth ) then
          TitanTreasury_DebugUtils( "Info", "help", 668, LB["TITAN_TREASURY_HELP_ADDAUTH"]:format( cmd ) );
          TitanTreasury_DebugUtils( "Info", "help", 669, LB["TITAN_TREASURY_HELP_REMAUTH"]:format( cmd ) );
     end
end

-- **************************************************************************
-- NAME : TitanTreasury_CommandHandler()
-- DESC : Slash command handler
-- **************************************************************************
function TitanTreasury_CommandHandler( slash, command )
     local cmd1, arg1, arg2
     _, _, cmd1, arg1, arg2 = strfind( strlower( string.lower( command ) ), "(%w+)[ ]?(%w*)[ ]?([-%w]*)" );
     if ( not cmd1 ) then cmd1 = string.lower( command ); end
     if ( not arg1 ) then arg11 = ""; end
     if ( not arg2 ) then arg2 = ""; end
     if ( cmd1 == "" or cmd1 == "help" ) then
          TitanTreasury_ShowHelp( slash );
     elseif ( cmd1 == "options" or cmd1 == "config" ) then
          InterfaceOptionsFrame_OpenToCategory( LB["TITAN_TREASURY_CONFIG"] );
     elseif ( cmd1 == "reset" ) then
          if ( arg1 == "all" or arg1 == "settings" ) then rLoad = true;
          else rLoad = false; end
          TitanTreasury_ResetUtils( rLoad, cmd1, arg1, arg2 );
     elseif ( cmd1 == "checkdb" ) then
          TitanTreasury_ResetUtils( false, cmd1 );
     elseif ( cmd1 == "addauth" ) then
          TitanTreasury_CoreUtils( cmd1 );
     elseif ( cmd1 == "remauth" ) then
          TitanTreasury_CoreUtils( cmd1 );
     elseif ( cmd1 == "ver" or cmd1 == "version" ) then
          TitanTreasury_DebugUtils( "Info", "VerCall", 698, ( "Your are using addon version |cff00ff00%s|r" ):format( TitanTreasury.General.Version ) );
	  TitanTreasury_DebugUtils( "Info", "VerCall", 699, ( "Data Array version |cff00ff00%s|r" ):format( TitanTreasury.General.ArrayVersion ) );
	  TitanTreasury_DebugUtils( "Info", "VerCall", 700, ( "Update addon version |cff00ff00%s|r" ):format( LB["TITAN_TREASURY_CORE_VERSION"] ) );
	  TitanTreasury_DebugUtils( "Info", "VerCall", 701, ( "Update data array version |cff00ff00%s|r" ):format( LB["TITAN_TREASURY_CORE_DBVER"] ) );
     else
          TitanTreasury_DebugUtils( "error", "CommandHandler", 703, LB["TITAN_TREASURY_HELP_ERROR"]:format( cmd1 ) );
     end
end
